@@ -28,7 +28,7 @@ def filed(key,inquire=[]):
         'getEtlPortIll': port.date().getEtlPortIll,
         'enity': ml.machine(inquire).inquire,
         'entityHost': kai.machine(inquire).inquireEntity,
-        'serviceKpiId': kai.machine(inquire).inquireServiceKpi,
+        'serviceKpiAlert': kai.machine(inquire).inquireServiceKpi,
         'businessKpiIdAndServiceId':kai.machine(inquire).inquireBusinessKPIAndServiceId,
         'ServiceBusinessID':kai.machine(inquire).ServiceBusiness,
         'pensInfo':kai.machine(inquire).inquirePens,
@@ -87,7 +87,9 @@ def filed(key,inquire=[]):
         'mailPass': testMail.date().getMailPass,
         'm_id': arPort.inputs().createarPortId,
         'now_times': ParaDateFiledServer().now_time,
-        'five_feature_times': ParaDateFiledServer().five_feature_time
+        'five_feature_times': ParaDateFiledServer().five_feature_time,
+        'getlocalhostIp':ip.date().getlocalhostIp,
+        'getNowYear':timestamp.date().getNowYear
     }
 
     switcher = SERVICE_KPI_
